package model.mygeography;

/**
 * The MyCity class is a simple shape class that
 * models a MyCity.
 *
 * Example Usage:
 *
 * 	MyCity city;
 *  city = MyCity.fromNameLatLong("Brooklyn Center", 45.076076, -93.332728);
 * 	prn(city.toString());
 * */
class MyCity {

	private String name;
	private GeoLocation location;

	//------------------------------------------
	// Constructing - public

	/** Returns new MyCity object with passed lat and long values */
	public static MyCity fromNameLatLong(String name, double lat, double lon) {
		return new MyCity(name, lat, lon);
	}

	/** Returns new MyCity object with name "Unnamed" and location (0, 0) */
	protected static MyCity newInstance() {
		return null;
	}

	//------------------------------------------
	// Constructing - private

	/** Constructs GeoLocation with passed lat and long values */
	private MyCity(String nm, double lat, double lon) {
		this.location.setLatitude(lat);
		this.location.setLongitude(lon);
	}

	//------------------------------------------
	//Calculations

	/** Returns true if this location is in the northern hemisphere */
	public boolean isInNorthernHemisphere() {
		return this.location.isInNorthernHemisphere();
	}

	/** Returns true if this location is north of passed latitude */
	public boolean isNorthOf(double aLatitude) {
		return this.location.isNorthOf(aLatitude);
	}

	/** Returns true if this location is south of passed latitude */
	public boolean isSouthOf(double aLatitude) {
		return this.location.isSouthOf(aLatitude);
	}

	//------------------------------------------
	//Common

	/** Returns nice display string for this MyCity */
	public String toString() {
		return String.format("%s %s",
				this.name.toString(),
				this.location.toString());
	}

}